# libpythonpro_zero
Study purpose

soportada versao python 3

Para instalar:
'''console
python3 -m venv .venv
windows:
.venv\scripts\activate
pip install -r requirements-dev.txt
'''

Para conferir qaulidade do codigo:
'''console
flake8
''''
